@@ -17,9 +17,6 @@
 /* Does your version of PGP support the PGPPASSFD environment variable? */
 #define HAVE_PGPPASSFD
 
-/* Disable the X-Mailer header? */
-#undef NO_XMAILER
-
 /* What is your domain name? */
 #undef DOMAIN
 
@@ -29,6 +26,9 @@
 /* use dotlocking to lock mailboxes? */
 #undef USE_DOTLOCK
 
+/* use an external dotlocking program? */
+#undef DL_STANDALONE
+
 /* use flock() to lock mailboxes? */
 #undef USE_FLOCK
 
@@ -143,3 +143,4 @@
 
 /* Where are the character set definitions located? */
 #undef CHARMAPS_DIR
+
