@@ -712,9 +712,11 @@ int mutt_save_attachment (FILE *fp, BODY *m, char *path, int flags, HEADER *hdr)
       
       memset (&s, 0, sizeof (s));
       if (flags == M_SAVE_APPEND)
-	s.fpout = safe_fopen (path, "a");
-      else
+	s.fpout = fopen (path, "a");
+      else if (flags == M_SAVE_OVERWRITE)
 	s.fpout = fopen (path, "w");
+      else
+	s.fpout = safe_fopen (path, "w");
       if (s.fpout == NULL)
       {
 	mutt_perror ("fopen");
@@ -776,9 +778,12 @@ int mutt_decode_save_attachment (FILE *fp, BODY *m, char *path,
   s.flags = (displaying ? M_DISPLAY : 0);
 
   if (flags == M_SAVE_APPEND)
-    s.fpout = safe_fopen (path, "a");
-  else
+    s.fpout = fopen (path, "a");
+  else if (flags == M_SAVE_OVERWRITE)
     s.fpout = fopen (path, "w");
+  else
+    s.fpout = safe_fopen (path, "w");
+
   if (s.fpout == NULL)
   {
     perror ("fopen");
