@@ -64,17 +64,16 @@ int Index_64[128] = {
     41,42,43,44, 45,46,47,48, 49,50,51,-1, -1,-1,-1,-1
 };
 
-void mutt_decode_xbit (STATE *s, BODY *b, int istext)
+void mutt_decode_xbit (STATE *s, BODY *b, int istext, DECODER *dec)
 {
   long len = b->length;
   int c, ch;
-  
+  int l = 0;
+
   if (istext)
   {
-    DECODER *dec = mutt_open_decoder (s, b, istext);
-
     state_set_prefix(s);
-    
+
     while ((c = fgetc(s->fpin)) != EOF && len--)
     {
       if(c == '\r' && len)
@@ -87,10 +86,18 @@ void mutt_decode_xbit (STATE *s, BODY *b, int istext)
 	else 
 	  ungetc(ch, s->fpin);
       }
-	
-      mutt_decoder_putc (dec, c);
+
+      mutt_decoder_push_one (dec, c);
+      if (l++ == 1024)
+      {
+	mutt_decoder_pop_to_state (dec, s);
+	l = 0;
+      }
     }
-    mutt_close_decoder (&dec);
+
+    mutt_decoder_push (dec, NULL, 0, NULL);
+    mutt_decoder_pop_to_state (dec, s);
+
     state_reset_prefix (s);
   }
   else
@@ -109,14 +116,14 @@ static int handler_state_fgetc(STATE *s)
   return ch;
 }
 
-void mutt_decode_quoted (STATE *s, BODY *b, int istext)
+void mutt_decode_quoted (STATE *s, BODY *b, int istext, DECODER *dec)
 {
   long len = b->length;
   int ch;
-  DECODER *dec = mutt_open_decoder (s, b, istext);
-  
+  int l = 0;
+
   state_set_prefix(s);
-  
+
   while (len > 0)
   {
     if ((ch = handler_state_fgetc(s)) == EOF)
@@ -171,20 +178,29 @@ void mutt_decode_quoted (STATE *s, BODY *b, int istext)
     }
 
     if(ch != EOF)
-      mutt_decoder_putc (dec, ch);
+    {
+      mutt_decoder_push_one (dec, ch);
+      if (l++ == 1024)
+      {
+	mutt_decoder_pop_to_state (dec, s);
+	l = 0;
+      }
+    }
   }
 
-  mutt_close_decoder (&dec);
+  mutt_decoder_push (dec, NULL, 0, NULL);
+  mutt_decoder_pop_to_state (dec, s);
+  
   state_reset_prefix(s);
 }
 
-void mutt_decode_base64 (STATE *s, BODY *b, int istext)
+void mutt_decode_base64 (STATE *s, BODY *b, int istext, DECODER *dec)
 {
   long len = b->length;
   char buf[5];
   int c1, c2, c3, c4, ch, cr = 0, i;
-  DECODER *dec = mutt_open_decoder (s, b, istext);
-  
+  size_t l = 0;
+
   buf[4] = 0;
 
   if (istext) state_set_prefix(s);
@@ -206,13 +222,17 @@ void mutt_decode_base64 (STATE *s, BODY *b, int istext)
     ch = (c1 << 2) | (c2 >> 4);
 
     if (cr && ch != '\n') 
-      mutt_decoder_putc (dec, '\r');
+    {
+      mutt_decoder_push_one (dec, '\r');
+    }
     cr = 0;
       
     if (istext && ch == '\r')
       cr = 1;
     else
-      mutt_decoder_putc (dec, ch);
+    {
+      mutt_decoder_push_one (dec, ch);
+    }
 
     if (buf[2] == '=')
       break;
@@ -220,29 +240,45 @@ void mutt_decode_base64 (STATE *s, BODY *b, int istext)
     ch = ((c2 & 0xf) << 4) | (c3 >> 2);
 
     if (cr && ch != '\n')
-      mutt_decoder_putc (dec, ch);
+    {
+      mutt_decoder_push_one (dec, ch);
+    }
 
     cr = 0;
 
     if (istext && ch == '\r')
       cr = 1;
     else
-      mutt_decoder_putc (dec, ch);
+    {
+      mutt_decoder_push_one (dec, ch);
+    }
 
     if (buf[3] == '=') break;
     c4 = base64val (buf[3]);
     ch = ((c3 & 0x3) << 6) | c4;
 
     if (cr && ch != '\n')
-      mutt_decoder_putc (dec, ch);
+    {
+      mutt_decoder_push_one (dec, ch);
+    }
     cr = 0;
 
     if (istext && ch == '\r')
       cr = 1;
     else
-      mutt_decoder_putc (dec, ch);
+    {
+      mutt_decoder_push_one (dec, ch);
+    }
+    
+    if ((l += 3) >= 1024)
+    {
+      mutt_decoder_pop_to_state (dec, s);
+      l = 0;
+    }
   }
-  mutt_close_decoder (&dec);
+  mutt_decoder_push (dec, NULL, 0, NULL);
+  mutt_decoder_pop_to_state (dec, s);
+
   state_reset_prefix(s);
 }
 
@@ -253,14 +289,13 @@ unsigned char decode_byte (char ch)
   return ch - 32;
 }
 
-void mutt_decode_uuencoded (STATE *s, BODY *b, int istext)
+void mutt_decode_uuencoded (STATE *s, BODY *b, int istext, DECODER *dec)
 {
   char tmps[SHORT_STRING];
   char linelen, c, l, out;
   char *pt;
   long len = b->length;
-  DECODER *dec = mutt_open_decoder (s, b, istext);
-  
+
   if(istext)
     state_set_prefix(s);
   
@@ -289,16 +324,19 @@ void mutt_decode_uuencoded (STATE *s, BODY *b, int istext)
 	out = decode_byte (*pt) << l;
 	pt++;
 	out |= (decode_byte (*pt) >> (6 - l));
-	mutt_decoder_putc (dec, out);
+	mutt_decoder_push_one (dec, out);
 	c++;
 	if (c == linelen)
 	  break;
       }
+      mutt_decoder_pop_to_state (dec, s);
       pt++;
     }
   }
 
-  mutt_close_decoder (&dec);
+  mutt_decoder_push (dec, NULL, 0, NULL);
+  mutt_decoder_pop_to_state (dec, s);
+  
   state_reset_prefix(s);
 }
 
@@ -1208,7 +1246,7 @@ static void external_body_handler (BODY *b, STATE *s)
 		     CH_DECODE , NULL);
     }
   }
-  else if(expire < time(NULL))
+  else if(expiration && expire < time(NULL))
   {
     if (s->flags & M_DISPLAY)
     {
@@ -1238,22 +1276,33 @@ static void external_body_handler (BODY *b, STATE *s)
 
 void mutt_decode_attachment (BODY *b, STATE *s)
 {
+  char *charset = mutt_get_parameter ("charset", b->parameter);
+  int istext = mutt_is_text_type (b->type, b->subtype);
+  DECODER *dec;
+
+  if (istext && s->flags & M_CHARCONV)
+    dec = mutt_open_decoder (charset, Charset);
+  else
+    dec = mutt_open_decoder (NULL, NULL);
+
   fseek (s->fpin, b->offset, 0);
   switch (b->encoding)
   {
     case ENCQUOTEDPRINTABLE:
-      mutt_decode_quoted (s, b, mutt_is_text_type (b->type, b->subtype));
+      mutt_decode_quoted (s, b, istext, dec);
       break;
     case ENCBASE64:
-      mutt_decode_base64 (s, b, mutt_is_text_type (b->type, b->subtype));
+      mutt_decode_base64 (s, b, istext, dec);
       break;
     case ENCUUENCODED:
-      mutt_decode_uuencoded (s, b, mutt_is_text_type (b->type, b->subtype));
+      mutt_decode_uuencoded (s, b, istext, dec);
       break;
     default:
-      mutt_decode_xbit (s, b, mutt_is_text_type (b->type, b->subtype));
+      mutt_decode_xbit (s, b, istext, dec);
       break;
   }
+
+  mutt_free_decoder (&dec);
 }
 
 void mutt_body_handler (BODY *b, STATE *s)
