@@ -36,6 +36,7 @@
 #define DT_SUBTYPE_MASK	0xf0
 #define DT_SORT_ALIAS	0x10
 #define DT_SORT_BROWSER 0x20
+#define DT_SORT_KEYS	0x40
 
 /* flags to parse_set() */
 #define M_SET_INV	(1<<0)	/* default is to invert all vars */
@@ -85,6 +86,7 @@ struct option_t MuttVars[] = {
   { "auto_tag",		DT_BOOL, R_NONE, OPTAUTOTAG, 0 },
   { "beep",		DT_BOOL, R_NONE, OPTBEEP, 1 },
   { "beep_new",		DT_BOOL, R_NONE, OPTBEEPNEW, 0 },
+  { "bounce_delivered", DT_BOOL, R_NONE, OPTBOUNCEDELIVERED, 1 },
   { "charset",		DT_STR,	 R_NONE, UL &Charset, UL "iso-8859-1" },
   { "check_new",	DT_BOOL, R_NONE, OPTCHECKNEW, 1 },
   { "collapse_unread",	DT_BOOL, R_NONE, OPTCOLLAPSEUNREAD, 1 },
@@ -111,6 +113,8 @@ struct option_t MuttVars[] = {
   { "folder_format",	DT_STR,	 R_NONE, UL &FolderFormat, UL "%N %F %2l %-8.8u %-8.8g %8s %d %f" },
   { "followup_to",	DT_BOOL, R_NONE, OPTFOLLOWUPTO, 1 },
   { "force_name",	DT_BOOL, R_NONE, OPTFORCENAME, 0 },
+  { "forward_attachment", DT_BOOL, R_NONE, OPTFORWATTACH, 0 },
+  { "forw_attachment",  DT_SYN, R_NONE, UL "forward_attachment", 0 },
   { "forward_decode",	DT_BOOL, R_NONE, OPTFORWDECODE, 1 },
   { "forw_decode",	DT_SYN,  R_NONE, UL "forward_decode", 0 },
   { "forward_weed",	DT_BOOL, R_NONE, OPTFORWWEEDHEADER, 1 },
@@ -221,6 +225,7 @@ struct option_t MuttVars[] = {
 # endif
   { "pgp_receive_version", 	DT_STR,	R_NONE, UL &PgpReceiveVersion, UL "default" },
   { "pgp_send_version",		DT_STR,	R_NONE, UL &PgpSendVersion, UL "default" },
+  { "pgp_sort_keys",	DT_SORT|DT_SORT_KEYS, R_NONE, UL &PgpSortKeys, SORT_ADDRESS },
   { "pgp_key_version",		DT_STR, R_NONE, UL &PgpKeyVersion, UL "default" },
 
   { "forward_decrypt",	DT_BOOL, R_NONE, OPTFORWDECRYPT, 1 },
@@ -329,6 +334,17 @@ const struct mapping_t SortAliasMethods[] = {
   { NULL }
 };
 
+#ifdef _PGPPATH
+const struct mapping_t SortKeyMethods[] = {
+  { "address",	SORT_ADDRESS },
+  { "date",	SORT_DATE },
+  { "keyid",	SORT_KEYID },
+  { "trust",	SORT_TRUST },
+  { NULL }
+};
+#endif /* _PGPPATH */
+
+
 /* functions used to parse commands in a rc file */
 
 static int parse_list (BUFFER *, BUFFER *, unsigned long, BUFFER *);
