@@ -1,4 +1,3 @@
-static const char rcsid[]="$Id: keymap.c,v 2.0 1998/12/12 08:06:33 roessler Rel $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -35,20 +34,22 @@ struct mapping_t Menus[] = {
  { "browser",	MENU_FOLDER },
  { "compose",	MENU_COMPOSE },
  { "editor",	MENU_EDITOR },
- { "generic",	MENU_GENERIC },
  { "index",	MENU_MAIN },
  { "pager",	MENU_PAGER },
  { "postpone",	MENU_POST },
 
-  
 
 #ifdef _PGPPATH
  { "pgp",	MENU_PGP },
 #endif  
   
+#ifdef MIXMASTER
+  { "mix", 	MENU_MIX },
+#endif
   
 
  { "query",	MENU_QUERY },
+ { "generic",	MENU_GENERIC },
  { NULL,	0 }
 };
 
@@ -534,7 +535,13 @@ void km_init (void)
   create_bindings (OpPgp, MENU_PGP);
 #endif
 
-
+#ifdef MIXMASTER
+  create_bindings (OpMix, MENU_MIX);
+  
+  km_bindkey ("<space>", MENU_MIX, OP_GENERIC_SELECT_ENTRY);
+  km_bindkey ("h", MENU_MIX, OP_MIX_CHAIN_PREV);
+  km_bindkey ("l", MENU_MIX, OP_MIX_CHAIN_NEXT);
+#endif
   
   /* bindings for the line editor */
   create_bindings (OpEditor, MENU_EDITOR);
@@ -729,6 +736,10 @@ struct binding_t *km_get_table (int menu)
 #endif
 
 
+#ifdef MIXMASTER
+    case MENU_MIX:
+      return OpMix;
+#endif
 
   }
   return NULL;
