@@ -86,6 +86,7 @@
 #define CH_UPDATE_LEN	(1<<10) /* update Lines: and Content-Length: */
 #define CH_TXTPLAIN	(1<<11) /* generate text/plain MIME headers */
 #define CH_NOLEN	(1<<12) /* don't write Content-Length: and Lines: */
+#define CH_WEED_DELIVERED (1<<13) /* weed eventual Delivered-To headers */
 
 /* flags for mutt_enter_string() */
 #define  M_ALIAS   1      /* do alias "completion" by calling up the alias-menu */
@@ -289,6 +290,7 @@ enum
   OPTAUTOTAG,
   OPTBEEP,
   OPTBEEPNEW,
+  OPTBOUNCEDELIVERED,
   OPTCHECKNEW,
   OPTCOLLAPSEUNREAD,
   OPTCONFIRMAPPEND,
@@ -299,6 +301,7 @@ enum
   OPTFCCATTACH,
   OPTFOLLOWUPTO,
   OPTFORCENAME,
+  OPTFORWATTACH,
   OPTFORWDECODE,
   OPTFORWWEEDHEADER,
   OPTFORWQUOTE,
