@@ -1102,7 +1102,9 @@ static void convert_to_7bit (BODY *a)
       a->encoding = ENCQUOTEDPRINTABLE;
     else if (a->encoding == ENCBINARY)
       a->encoding = ENCBASE64;
-    else if (a->content && (a->content->from || (a->content->space && option (OPTPGPSTRICTENC))))
+    else if (a->content && a->encoding != ENCBASE64 &&
+	     (a->content->from || (a->content->space && 
+				   option (OPTPGPSTRICTENC))))
       a->encoding = ENCQUOTEDPRINTABLE;
     a = a->next;
   }
@@ -1447,20 +1449,43 @@ int pgp_get_keys (HEADER *msg, char **pgpkeylist)
 int pgp_protect (HEADER *msg, char *pgpkeylist)
 {
   BODY *pbody = NULL;
+  int flags = msg->pgp;
 
   if ((msg->pgp & PGPSIGN) && !pgp_valid_passphrase ())
     return (-1);
 
   if (!isendwin ())
     endwin ();
-  if (msg->pgp & PGPENCRYPT)
-    pbody = pgp_encrypt_message (msg->content, pgpkeylist, msg->pgp & PGPSIGN);
-  else if (msg->pgp & PGPSIGN)
-    pbody = pgp_sign_message (msg->content);
 
-  if (!pbody)
-    return (-1);
-  msg->content = pbody;
+  if ((flags & PGPSIGN) && (!(flags & PGPENCRYPT) || option (OPTPGPRETAINABLESIG)))
+  {
+    if (!(pbody = pgp_sign_message (msg->content)))
+      return -1;
+
+    msg->content = pbody;
+    flags &= ~PGPSIGN;
+  }
+
+  if (flags & PGPENCRYPT)
+  {
+    if (!(pbody = pgp_encrypt_message (msg->content, pgpkeylist, flags & PGPSIGN)))
+    {
+
+      /* did we perform a retainable signature? */
+      if (flags != msg->pgp)
+      {
+	/* remove the outer multipart layer */
+	msg->content = mutt_remove_multipart (msg->content);
+	/* get rid of the signature */
+	mutt_free_body (&msg->content->next);
+      }
+
+      return (-1);
+    }
+
+    msg->content = pbody;
+  }
+
   return (0);
 }
 
