@@ -26,6 +26,7 @@
 #include "mime.h"
 #include "pgp.h"
 #include "pager.h"
+#include "sort.h"
 
 #include <string.h>
 #include <ctype.h>
@@ -97,12 +98,13 @@ static pgp_key_t *pgp_principal_key (pgp_key_t *key)
  * 
  * %n	number
  * %k	key id		%K 	key id of the principal key
- * %u	uiser id
+ * %u	user id
  * %a	algorithm	%A      algorithm of the princ. key
  * %l	length		%L	length of the princ. key
  * %f	flags		%F 	flags of the princ. key
  * %c	capabilities	%C	capabilities of the princ. key
  * %t	trust/validity of the key-uid association
+ * %[...] date of key using strftime(3)
  */
 
 typedef struct pgp_entry
@@ -144,6 +146,66 @@ static const char *pgp_entry_fmt (char *dest,
   
   switch (tolower (op))
   {
+    case '[':
+
+      {
+	const char *cp;
+	char buf2[SHORT_STRING], *p;
+	int do_locales;
+	struct tm *tm;
+	size_t len;
+
+	p = dest;
+
+	cp = src;
+	if (*cp == '!')
+	{
+	  do_locales = 0;
+	  cp++;
+	}
+	else
+	  do_locales = 1;
+
+	len = destlen - 1;
+	while (len > 0 && *cp != ']')
+	{
+	  if (*cp == '%')
+	  {
+	    cp++;
+	    if (len >= 2)
+	    {
+	      *p++ = '%';
+	      *p++ = *cp;
+	      len -= 2;
+	    }
+	    else
+	      break; /* not enough space */
+	    cp++;
+	  }
+	  else
+	  {
+	    *p++ = *cp++;
+	    len--;
+	  }
+	}
+	*p = 0;
+
+	if (do_locales && Locale)
+	  setlocale (LC_TIME, Locale);
+
+	tm = localtime (&key->gen_time);
+
+	strftime (buf2, sizeof (buf2), dest, tm);
+
+	if (do_locales)
+	  setlocale (LC_TIME, "C");
+
+	snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
+	snprintf (dest, destlen, fmt, buf2);
+	if (len > 0)
+	  src = cp + 1;
+      }
+      break;
     case 'n':
       if (!optional)
       {
@@ -229,18 +291,92 @@ static void pgp_entry (char *s, size_t l, MUTTMENU * menu, int num)
   mutt_FormatString (s, l, NONULL (PgpEntryFormat), pgp_entry_fmt, 
 		     (unsigned long) &entry, M_FORMAT_ARROWCURSOR);
 }
-  
-static int pgp_compare (const void *a, const void *b)
+
+static int _pgp_compare_address (const void *a, const void *b)
 {
   int r;
 
   pgp_uid_t **s = (pgp_uid_t **) a;
   pgp_uid_t **t = (pgp_uid_t **) b;
 
-  if ((r = mutt_strcasecmp ((*s)->addr, (*t)->addr)) != 0)
-    return r;
+  if ((r = mutt_strcasecmp ((*s)->addr, (*t)->addr)))
+    return r > 0;
   else
-    return mutt_strcasecmp (pgp_keyid ((*s)->parent), pgp_keyid ((*t)->parent));
+    return (mutt_strcasecmp (pgp_keyid ((*s)->parent),
+			     pgp_keyid ((*t)->parent)) > 0);
+}
+
+static int pgp_compare_address (const void *a, const void *b)
+{
+  return ((PgpSortKeys & SORT_REVERSE) ? !_pgp_compare_address (a, b)
+				       : _pgp_compare_address (a, b));
+}
+
+
+
+static int _pgp_compare_keyid (const void *a, const void *b)
+{
+  int r;
+
+  pgp_uid_t **s = (pgp_uid_t **) a;
+  pgp_uid_t **t = (pgp_uid_t **) b;
+
+  if ((r = mutt_strcasecmp (pgp_keyid ((*s)->parent), 
+			    pgp_keyid ((*t)->parent))))
+    return r > 0;
+  else
+    return (mutt_strcasecmp ((*s)->addr, (*t)->addr)) > 0;
+}
+
+static int pgp_compare_keyid (const void *a, const void *b)
+{
+  return ((PgpSortKeys & SORT_REVERSE) ? !_pgp_compare_keyid (a, b)
+				       : _pgp_compare_keyid (a, b));
+}
+
+static int _pgp_compare_date (const void *a, const void *b)
+{
+  int r;
+  pgp_uid_t **s = (pgp_uid_t **) a;
+  pgp_uid_t **t = (pgp_uid_t **) b;
+
+  if ((r = ((*s)->parent->gen_time - (*t)->parent->gen_time)))
+    return r > 0;
+  return (mutt_strcasecmp ((*s)->addr, (*t)->addr)) > 0;
+}
+
+static int pgp_compare_date (const void *a, const void *b)
+{
+  return ((PgpSortKeys & SORT_REVERSE) ? !_pgp_compare_date (a, b)
+				       : _pgp_compare_date (a, b));
+}
+
+static int _pgp_compare_trust (const void *a, const void *b)
+{
+  int r;
+
+  pgp_uid_t **s = (pgp_uid_t **) a;
+  pgp_uid_t **t = (pgp_uid_t **) b;
+
+  if ((r = (((*s)->parent->flags & (KEYFLAG_RESTRICTIONS))
+	    - ((*t)->parent->flags & (KEYFLAG_RESTRICTIONS)))))
+    return r > 0;
+  if ((r = ((*s)->trust - (*t)->trust)))
+    return r < 0;
+  if ((r = ((*s)->parent->keylen - (*t)->parent->keylen)))
+    return r < 0;
+  if ((r = ((*s)->parent->gen_time - (*t)->parent->gen_time)))
+    return r < 0;
+  if ((r = mutt_strcasecmp ((*s)->addr, (*t)->addr)))
+    return r > 0;
+  return (mutt_strcasecmp (pgp_keyid ((*s)->parent), 
+			   pgp_keyid ((*t)->parent))) > 0;
+}
+
+static int pgp_compare_trust (const void *a, const void *b)
+{
+  return ((PgpSortKeys & SORT_REVERSE) ? !_pgp_compare_trust (a, b)
+				       : _pgp_compare_trust (a, b));
 }
 
 static pgp_key_t *pgp_select_key (struct pgp_vinfo *pgp,
@@ -257,6 +393,7 @@ static pgp_key_t *pgp_select_key (struct pgp_vinfo *pgp,
   pid_t thepid;
   pgp_key_t *kp;
   pgp_uid_t *a;
+  int (*f) (const void *, const void *);
 
   for (i = 0, kp = keys; kp; kp = kp->next)
   {
@@ -282,7 +419,23 @@ static pgp_key_t *pgp_select_key (struct pgp_vinfo *pgp,
       KeyTable[i] = a;
   }
 
-  qsort (KeyTable, i, sizeof (pgp_key_t *), pgp_compare);
+  switch (PgpSortKeys & SORT_MASK)
+  {
+    case SORT_DATE:
+      f = pgp_compare_date;
+      break;
+    case SORT_KEYID:
+      f = pgp_compare_keyid;
+      break;
+    case SORT_ADDRESS:
+      f = pgp_compare_address;
+      break;
+    case SORT_TRUST:
+    default:
+      f = pgp_compare_trust;
+      break;
+  }
+  qsort (KeyTable, i, sizeof (pgp_key_t *), f);
 
   helpstr[0] = 0;
   mutt_make_help (buf, sizeof (buf), _("Exit  "), MENU_PGP, OP_EXIT);
