@@ -111,6 +111,7 @@ ATTACHPTR **mutt_gen_attach_list (BODY *m,
       safe_realloc ((void **) &idx, sizeof (ATTACHPTR *) * (*idxmax += 5));
 
     if (m->type == TYPEMULTIPART && m->parts
+	&& (compose || (parent_type == -1 && mutt_strcasecmp ("alternative", m->subtype)))
 #ifdef _PGPPATH
 	&& !mutt_is_multipart_encrypted(m)
 #endif
@@ -124,9 +125,17 @@ ATTACHPTR **mutt_gen_attach_list (BODY *m,
       new->content = m;
       new->parent_type = parent_type;
       new->level = level;
+      /* called when creating new menu, so clear the tagged indicator */
+      m->tagged = 0;
 
       /* We don't support multipart messages in the compose menu yet */
-      if (!compose && mutt_is_message_type(m->type, m->subtype))
+      if (!compose && 
+	  ((m->type == TYPEMULTIPART
+#ifdef _PGPPATH
+	    && !mutt_is_multipart_encrypted (m)
+#endif
+	    )
+	   || mutt_is_message_type(m->type, m->subtype)))
       {
 	idx = mutt_gen_attach_list (m->parts, m->type, idx, idxlen, idxmax, level + 1, compose);
       }
@@ -814,12 +823,39 @@ static void reply_attachment_list (int op, int tag, HEADER *hdr, BODY *body)
     ctx = mx_open_mailbox (tempfile, M_QUIET, NULL);
     hn = ctx->hdrs[0];
   }
+  
+  if (op == SENDFORWARD && option (OPTFORWATTACH))
+  {
+    HEADER *newhdr = mutt_new_header();
+    char buffer [LONG_STRING];
 
-  ci_send_message (op, NULL, NULL, ctx, hn);
+    mutt_message ("Preparing to forward...");
+    if (mutt_prepare_edit_message (ctx, newhdr, hn) < 0)
+    {
+      mutt_clear_error();
+      mutt_free_header (&newhdr);
+      goto cleanup;
+    }
+
+    mutt_free_envelope (&newhdr->env);
+    newhdr->env = mutt_new_envelope();
+
+    /* set the default subject for the message. */
+    buffer[0] = 0;
+    mutt_make_string (buffer, sizeof (buffer), NONULL(ForwFmt), ctx, hn);
+    newhdr->env->subject = safe_strdup (buffer);
+
+    mutt_clear_error();
+    ci_send_message (0, newhdr, NULL, ctx, NULL);
+  }
+  else
+    ci_send_message (op, NULL, NULL, ctx, hn);
 
   if (hn->replied && !hdr->replied)
     mutt_set_flag (Context, hdr, M_REPLIED, 1);
 
+cleanup:
+
   if (ctx != Context)
   {
     mx_fastclose_mailbox (ctx);
