@@ -340,7 +340,7 @@ static int include_forward (CONTEXT *ctx, HEADER *cur, FILE *out)
     cmflags |= M_CM_DECODE | M_CM_CHARCONV;
     if (option (OPTFORWWEEDHEADER))
     {
-      chflags |= CH_WEED;
+      chflags |= CH_WEED | CH_REORDER;
       cmflags |= M_CM_WEED;
     }
   }
@@ -1135,7 +1135,7 @@ ci_send_message (int flags,		/* send mode */
   /* specify a default fcc.  if we are in batchmode, only save a copy of
    * the message if the value of $copy is yes or ask-yes */
 
-  if (!fcc[0] && (!(flags & SENDBATCH) || (quadoption (OPT_COPY) & 0x1)))
+  if (!fcc[0] && !(flags & SENDPOSTPONED) && (!(flags & SENDBATCH) || (quadoption (OPT_COPY) & 0x1)))
   {
     /* set the default FCC */
     if (!msg->env->from)
@@ -1255,12 +1255,22 @@ main_loop:
   mutt_expand_path (fcc, sizeof (fcc));
   if (*fcc && mutt_strcmp ("/dev/null", fcc) != 0)
   {
+    struct stat st;
     BODY *tmpbody = msg->content;
 #ifdef _PGPPATH
     BODY *save_sig = NULL;
     BODY *save_parts = NULL;
 #endif /* _PGPPATH */
 
+    /* honor $confirmcreate and $confirmappend  in interactive mode */
+    if (!option (OPTNOCURSES) && !(flags & SENDMAILX) && 
+	!mutt_save_confirm (fcc, &st))
+    {
+      mutt_pretty_mailbox (fcc);
+      mutt_clear_error();
+      goto main_loop;
+    }
+
     /* check to see if the user wants copies of all attachments */
     if (!option (OPTFCCATTACH) && msg->content->type == TYPEMULTIPART)
     {
