@@ -1054,6 +1054,7 @@ BODY *mutt_make_file_attach (const char *path)
   /* Attempt to determine the appropriate content-type based on the filename
    * suffix.
    */
+
   if ((n = lookup_mime_type (buf, path)) != TYPEOTHER)
   {
     att->type = n;
@@ -1070,7 +1071,6 @@ BODY *mutt_make_file_attach (const char *path)
        */
       att->type = TYPETEXT;
       att->subtype = safe_strdup ("plain");
-      mutt_set_body_charset(att, get_text_charset(att, info));
     }
     else
     {
@@ -1079,9 +1079,14 @@ BODY *mutt_make_file_attach (const char *path)
     }
   } 
 
+  /* XXX - just call mutt_update_encoding? -tlr */
+
   mutt_set_encoding (att, info);
   mutt_stamp_attachment(att);
 
+  if (att->type == TYPETEXT)
+    mutt_set_body_charset(att, get_text_charset(att, info));
+  
 #ifdef _PGPPATH
   /*
    * save the info in case this message is signed.  we will want to do Q-P
@@ -1092,8 +1097,6 @@ BODY *mutt_make_file_attach (const char *path)
   info = NULL;
 #endif
 
-
-
   safe_free ((void **) &info);
 
   return (att);
@@ -1122,7 +1125,7 @@ BODY *mutt_make_multipart (BODY *b)
   new->type = TYPEMULTIPART;
   new->subtype = safe_strdup ("mixed");
   new->encoding = get_toplevel_encoding (b);
-  mutt_generate_boundary(&new->parameter);
+  mutt_generate_boundary (&new->parameter);
   new->use_disp = 0;  
   new->parts = b;
 
@@ -1821,9 +1824,13 @@ void mutt_bounce_message (HEADER *h, ADDRESS *to)
     if ((f = safe_fopen (tempfile, "w")) != NULL)
     {
       const char *fqdn;
-
+      int ch_flags = CH_XMIT | CH_NONEWLINE;
+      
+      if (!option (OPTBOUNCEDELIVERED))
+	ch_flags |= CH_WEED_DELIVERED;
+      
       fseek (msg->fp, h->offset, 0);
-      mutt_copy_header (msg->fp, h, f, CH_XMIT | CH_NONEWLINE, NULL);
+      mutt_copy_header (msg->fp, h, f, ch_flags, NULL);
       fprintf (f, "Resent-From: %s", NONULL(Username));
       if((fqdn = mutt_fqdn(1)))
 	fprintf (f, "@%s", fqdn);
